@@ -3,7 +3,7 @@
 import operator
 import re
 from ipaddress import ip_address
-import functools
+# import functools
 import traceback
 import logging
 from datetime import datetime
@@ -92,38 +92,38 @@ def validate_interface(iface_name, pattern='', valid=True, on_exception=True):
         return result
 
 
-def false_on_exception_for_classmethod(func):
-    """Wrap the classmethod and return False on exception.
-
-    Parameters
-    ----------
-    func (function): a callable function
-
-    Notes
-    -----
-    DO NOT nest this decorator.
-    """
-    @functools.wraps(func)
-    def wrapper_func(*args, **kwargs):
-        """A Wrapper Function"""
-        chk = str(args[1]).upper()
-        if chk == '__EXCEPTION__':
-            return False
-        try:
-            result = func(*args, **kwargs)
-            return result if kwargs.get('valid', True) else not result
-        except Exception as ex:
-            if DEBUG:
-                traceback.print_exc()
-            else:
-                msg = 'Warning *** {}: {}'.format(type(ex).__name__, ex)
-                logger.warning(msg)
-            is_called_exception = kwargs.get('on_exception', False)
-            if is_called_exception:
-                raise ex
-            else:
-                return False if kwargs.get('valid', True) else True
-    return wrapper_func
+# def false_on_exception_for_classmethod(func):
+#     """Wrap the classmethod and return False on exception.
+#
+#     Parameters
+#     ----------
+#     func (function): a callable function
+#
+#     Notes
+#     -----
+#     DO NOT nest this decorator.
+#     """
+#     @functools.wraps(func)
+#     def wrapper_func(*args, **kwargs):
+#         """A Wrapper Function"""
+#         chk = str(args[1]).upper()
+#         if chk == '__EXCEPTION__':
+#             return False
+#         try:
+#             result = func(*args, **kwargs)
+#             return result if kwargs.get('valid', True) else not result
+#         except Exception as ex:
+#             if DEBUG:
+#                 traceback.print_exc()
+#             else:
+#                 msg = 'Warning *** {}: {}'.format(type(ex).__name__, ex)
+#                 logger.warning(msg)
+#             is_called_exception = kwargs.get('on_exception', False)
+#             if is_called_exception:
+#                 raise ex
+#             else:
+#                 return False if kwargs.get('valid', True) else True
+#     return wrapper_func
 
 
 def raise_exception_if(ex, on_exception=True):
@@ -756,13 +756,23 @@ class CustomValidation:
             if matched_date:
                 return True if valid else False
 
-            month_names_pattern = ('(?i)[ADFJMNOS][aceopu][bcglnprtvy]'
-                                   '([abceimorstu]*[ehlrt])?')
+            month_names_pattern = """(?ix)jan(uary)?|
+                                     feb(ruary)?|
+                                     mar(ch)?|
+                                     apr(il)?|
+                                     may|
+                                     june?|
+                                     july?|
+                                     aug(ust)?|
+                                     sep(tember)?|
+                                     oct(ober)?|
+                                     nov(ember)?|
+                                     dec(ember)?"""
             matched_month_names = re.search(month_names_pattern, value)
             if matched_month_names:
                 return True if valid else False
 
-            day_names_pattern = '(?i)[FMSTW][aehoru][deintu]([enrsu]*day)?'
+            day_names_pattern = '(?i)(sun|mon|tues?|wed(nes)?|thu(rs)?|fri|sat(ur)?)(day)?'
             matched_day_names = re.search(day_names_pattern, value)
             if matched_day_names:
                 return True if valid else False
@@ -807,13 +817,23 @@ class CustomValidation:
             if matched_date:
                 return True if valid else False
 
-            month_names_pattern = ('(?i)[ADFJMNOS][aceopu][bcglnprtvy]'
-                                   '([abceimorstu]*[ehlrt])?')
+            month_names_pattern = """(?ix)jan(uary)?|
+                                     feb(ruary)?|
+                                     mar(ch)?|
+                                     apr(il)?|
+                                     may|
+                                     june?|
+                                     july?|
+                                     aug(ust)?|
+                                     sep(tember)?|
+                                     oct(ober)?|
+                                     nov(ember)?|
+                                     dec(ember)?"""
             matched_month_names = re.search(month_names_pattern, value)
             if matched_month_names:
                 return True if valid else False
 
-            day_names_pattern = '(?i)[FMSTW][aehoru][deintu]([enrsu]*day)?'
+            day_names_pattern = '(?i)(sun|mon|tues?|wed(nes)?|thu(rs)?|fri|sat(ur)?)(day)?'
             matched_day_names = re.search(day_names_pattern, value)
             if matched_day_names:
                 return True if valid else False
@@ -852,13 +872,23 @@ class CustomValidation:
             if matched_date:
                 return False if valid else True
 
-            month_names_pattern = ('(?i)[ADFJMNOS][aceopu][bcglnprtvy]'
-                                   '([abceimorstu]*[ehlrt])?')
+            month_names_pattern = """(?ix)jan(uary)?|
+                                     feb(ruary)?|
+                                     mar(ch)?|
+                                     apr(il)?|
+                                     may|
+                                     june?|
+                                     july?|
+                                     aug(ust)?|
+                                     sep(tember)?|
+                                     oct(ober)?|
+                                     nov(ember)?|
+                                     dec(ember)?"""
             matched_month_names = re.search(month_names_pattern, value)
             if matched_month_names:
                 return False if valid else True
 
-            day_names_pattern = '(?i)[FMSTW][aehoru][deintu]([enrsu]*day)?'
+            day_names_pattern = '(?i)(sun|mon|tues?|wed(nes)?|thu(rs)?|fri|sat(ur)?)(day)?'
             matched_day_names = re.search(day_names_pattern, value)
             if matched_day_names:
                 return False if valid else True
